==> ui-18.0.4.tgz: package/components/_transition/CollapseTransition.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import { useRef } from 'react';
import { DTransition } from './Transition';
export function DCollapseTransition(props) {
    const { children, dStyles } = props, restProps = __rest(props, ["children", "dStyles"]);
    const [dOriginalSize, dCollapsedStyle] = [restProps.dOriginalSize, restProps.dCollapsedStyle];
    const ref = useRef(null);
    const dataRef = useRef({
        width: 0,
        height: 0,
    });
    const isHorizontal = !isUndefined(dOriginalSize.width);
    const getSizeStyle = (val) => (isUndefined(val) ? '' : isNumber(val) ? `${val}px` : val);
    return (_jsx(DTransition, Object.assign({}, restProps, { onEnter: () => {
            var _a, _b, _c, _d, _e;
            (_a = restProps.onEnter) === null || _a === void 0 ? void 0 : _a.call(restProps);
            if (ref.current) {
                if (dOriginalSize.width === 'auto') {
                    const cssText = ref.current.style.cssText;
                    ref.current.style.width = 'auto';
                    ref.current.style.paddingLeft = getSizeStyle((_b = dOriginalSize.padding) === null || _b === void 0 ? void 0 : _b[3]);
                    ref.current.style.paddingRight = getSizeStyle((_c = dOriginalSize.padding) === null || _c === void 0 ? void 0 : _c[1]);
                    dataRef.current.width = ref.current.offsetWidth;
                    ref.current.style.cssText = cssText;
                    // eslint-disable-next-line @typescript-eslint/no-unused-expressions
                    ref.current.offsetTop;
                }
                else if (dOriginalSize.height === 'auto') {
                    const cssText = ref.current.style.cssText;
                    ref.current.style.height = 'auto';
                    ref.current.style.paddingTop = getSizeStyle((_d = dOriginalSize.padding) === null || _d === void 0 ? void 0 : _d[0]);
                    ref.current.style.paddingBottom = getSizeStyle((_e = dOriginalSize.padding) === null || _e === void 0 ? void 0 : _e[2]);
                    dataRef.current.height = ref.current.offsetHeight;
                    ref.current.style.cssText = cssText;
                    // eslint-disable-next-line @typescript-eslint/no-unused-expressions
                    ref.current.offsetTop;
                }
            }
        } }, { children: (state) => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r;
            const transitionStyle = Object.assign({}, dStyles[state]);
            const originalSize = {
                [isHorizontal ? 'width' : 'height']: isHorizontal
                    ? dOriginalSize.width === 'auto'
                        ? dataRef.current.width
                        : dOriginalSize.width
                    : dOriginalSize.height === 'auto'
                        ? dataRef.current.height
                        : dOriginalSize.height,
            };
            if (!isUndefined(dOriginalSize.padding)) {
                originalSize.padding = dOriginalSize.padding.map((p) => getSizeStyle(p)).join(' ');
            }
            const collapsedStyle = Object.assign({
                [isHorizontal ? 'width' : 'height']: dCollapsedStyle[isHorizontal ? 'width' : 'height'],
                overflow: 'hidden',
            }, isHorizontal
                ? {
                    paddingLeft: (_b = (_a = dCollapsedStyle.padding) === null || _a === void 0 ? void 0 : _a[3]) !== null && _b !== void 0 ? _b : 0,
                    paddingRight: (_d = (_c = dCollapsedStyle.padding) === null || _c === void 0 ? void 0 : _c[1]) !== null && _d !== void 0 ? _d : 0,
                    marginLeft: (_f = (_e = dCollapsedStyle.margin) === null || _e === void 0 ? void 0 : _e[3]) !== null && _f !== void 0 ? _f : 0,
                    marginRight: (_h = (_g = dCollapsedStyle.margin) === null || _g === void 0 ? void 0 : _g[1]) !== null && _h !== void 0 ? _h : 0,
                }
                : {
                    paddingTop: (_k = (_j = dCollapsedStyle.padding) === null || _j === void 0 ? void 0 : _j[0]) !== null && _k !== void 0 ? _k : 0,
                    paddingBottom: (_m = (_l = dCollapsedStyle.padding) === null || _l === void 0 ? void 0 : _l[2]) !== null && _m !== void 0 ? _m : 0,
                    marginTop: (_p = (_o = dCollapsedStyle.margin) === null || _o === void 0 ? void 0 : _o[0]) !== null && _p !== void 0 ? _p : 0,
                    marginBottom: (_r = (_q = dCollapsedStyle.margin) === null || _q === void 0 ? void 0 : _q[2]) !== null && _r !== void 0 ? _r : 0,
                });
            switch (state) {
                case 'enter':
                    Object.assign(transitionStyle, collapsedStyle);
                    break;
                case 'entering':
                    Object.assign(transitionStyle, originalSize, {
                        overflow: 'hidden',
                    });
                    break;
                case 'leave':
                    Object.assign(transitionStyle, originalSize, {
                        overflow: 'hidden',
                    });
                    break;
                case 'leaving':
                    Object.assign(transitionStyle, collapsedStyle);
                    break;
                case 'leaved':
                    Object.assign(transitionStyle, collapsedStyle, {
                        overflow: 'hidden',
                    });
                    break;
                default:
                    break;
            }
            return children(ref, transitionStyle, state);
        } })));
}

==> ui-18.4.1.tgz: package/components/_transition/CollapseTransition.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isNumber, isUndefined } from 'lodash';
import { useRef } from 'react';
import { DTransition } from './Transition';
export function DCollapseTransition(props) {
    const { children, dStyles } = props, restProps = __rest(props, ["children", "dStyles"]);
    const [dOriginalSize, dCollapsedStyle] = [restProps.dOriginalSize, restProps.dCollapsedStyle];
    const ref = useRef(null);
    const dataRef = useRef({
        width: 0,
        height: 0,
    });
    const isHorizontal = !isUndefined(dOriginalSize.width);
    const getSizeStyle = (val) => (isUndefined(val) ? '' : isNumber(val) ? `${val}px` : val);
    return (_jsx(DTransition, Object.assign({}, restProps, { onEnter: () => {
            var _a, _b, _c, _d, _e;
            (_a = restProps.onEnter) === null || _a === void 0 ? void 0 : _a.call(restProps);
            if (ref.current) {
                if (dOriginalSize.width === 'auto') {
                    const cssText = ref.current.style.cssText;
                    ref.current.style.width = 'auto';
                    ref.current.style.paddingLeft = getSizeStyle((_b = dOriginalSize.padding) === null || _b === void 0 ? void 0 : _b[3]);
                    ref.current.style.paddingRight = getSizeStyle((_c = dOriginalSize.padding) === null || _c === void 0 ? void 0 : _c[1]);
                    dataRef.current.width = ref.current.offsetWidth;
                    ref.current.style.cssText = cssText;
                    // eslint-disable-next-line @typescript-eslint/no-unused-expressions
                    ref.current.offsetTop;
                }
                else if (dOriginalSize.height === 'auto') {
                    const cssText = ref.current.style.cssText;
                    ref.current.style.height = 'auto';
                    ref.current.style.paddingTop = getSizeStyle((_d = dOriginalSize.padding) === null || _d === void 0 ? void 0 : _d[0]);
                    ref.current.style.paddingBottom = getSizeStyle((_e = dOriginalSize.padding) === null || _e === void 0 ? void 0 : _e[2]);
                    dataRef.current.height = ref.current.offsetHeight;
                    ref.current.style.cssText = cssText;
                    // eslint-disable-next-line @typescript-eslint/no-unused-expressions
                    ref.current.offsetTop;
                }
            }
        } }, { children: (state) => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s;
            const transitionStyle = Object.assign({}, dStyles[state]);
            const originalSize = {
                [isHorizontal ? 'width' : 'height']: isHorizontal
                    ? dOriginalSize.width === 'auto'
                        ? dataRef.current.width
                        : dOriginalSize.width
                    : dOriginalSize.height === 'auto'
                        ? dataRef.current.height
                        : dOriginalSize.height,
            };
            if (!isUndefined(dOriginalSize.padding)) {
                originalSize.padding = dOriginalSize.padding.map((p) => getSizeStyle(p)).join(' ');
            }
            const collapsedStyle = Object.assign({
                [isHorizontal ? 'width' : 'height']: dCollapsedStyle[isHorizontal ? 'width' : 'height'],
                overflow: 'hidden',
            }, isHorizontal
                ? {
                    paddingLeft: (_b = (_a = dCollapsedStyle.padding) === null || _a === void 0 ? void 0 : _a[3]) !== null && _b !== void 0 ? _b : 0,
                    paddingRight: (_d = (_c = dCollapsedStyle.padding) === null || _c === void 0 ? void 0 : _c[1]) !== null && _d !== void 0 ? _d : 0,
                    marginLeft: (_f = (_e = dCollapsedStyle.margin) === null || _e === void 0 ? void 0 : _e[3]) !== null && _f !== void 0 ? _f : 0,
                    marginRight: (_h = (_g = dCollapsedStyle.margin) === null || _g === void 0 ? void 0 : _g[1]) !== null && _h !== void 0 ? _h : 0,
                }
                : {
                    paddingTop: (_k = (_j = dCollapsedStyle.padding) === null || _j === void 0 ? void 0 : _j[0]) !== null && _k !== void 0 ? _k : 0,
                    paddingBottom: (_m = (_l = dCollapsedStyle.padding) === null || _l === void 0 ? void 0 : _l[2]) !== null && _m !== void 0 ? _m : 0,
                    marginTop: (_p = (_o = dCollapsedStyle.margin) === null || _o === void 0 ? void 0 : _o[0]) !== null && _p !== void 0 ? _p : 0,
                    marginBottom: (_r = (_q = dCollapsedStyle.margin) === null || _q === void 0 ? void 0 : _q[2]) !== null && _r !== void 0 ? _r : 0,
                });
            switch (state) {
                case 'enter':
                    Object.assign(transitionStyle, collapsedStyle);
                    break;
                case 'entering':
                    Object.assign(transitionStyle, originalSize, {
                        overflow: 'hidden',
                    });
                    break;
                case 'leave':
                    if (originalSize[isHorizontal ? 'width' : 'height'] === 0) {
                        originalSize[isHorizontal ? 'width' : 'height'] = (_s = ref.current) === null || _s === void 0 ? void 0 : _s[isHorizontal ? 'offsetWidth' : 'offsetHeight'];
                    }
                    Object.assign(transitionStyle, originalSize, {
                        overflow: 'hidden',
                    });
                    break;
                case 'leaving':
                    Object.assign(transitionStyle, collapsedStyle);
                    break;
                case 'leaved':
                    Object.assign(transitionStyle, collapsedStyle, {
                        overflow: 'hidden',
                    });
                    break;
                default:
                    break;
            }
            return children(ref, transitionStyle, state);
        } })));
}
